@@ -95,10 +95,7 @@ pub use self::{
 pub use self::permission::InMemoryCachePermissions;
 
 use self::model::*;
-use dashmap::{
-    mapref::{entry::Entry, one::Ref},
-    DashMap, DashSet,
-};
+use dashmap::{mapref::entry::Entry, DashMap, DashSet};
 use std::{
     collections::{BTreeSet, HashSet, VecDeque},
     hash::Hash,
@@ -534,17 +531,6 @@ impl InMemoryCache {
         self.0.users.get(&user_id).map(|r| r.0.clone())
     }
 
-    /// Gets a user by ID.
-    ///
-    /// This is an O(1) operation. This requires the [`GUILD_MEMBERS`] intent.
-    ///
-    /// [`GUILD_MEMBERS`]: ::twilight_model::gateway::Intents::GUILD_MEMBERS
-    #[deprecated(since = "0.5.1", note = "use `user`")]
-    #[doc(hidden)]
-    pub fn user_ref(&self, user_id: UserId) -> Option<Ref<'_, UserId, (User, BTreeSet<GuildId>)>> {
-        self.0.users.get(&user_id)
-    }
-
     /// Gets the voice states within a voice channel.
     ///
     /// This requires both the [`GUILDS`] and [`GUILD_VOICE_STATES`] intents.
@@ -557,7 +543,7 @@ impl InMemoryCache {
         Some(
             user_ids
                 .iter()
-                .filter_map(|key| self.0.voice_states.get(&key).map(|r| r.clone()))
+                .filter_map(|key| self.0.voice_states.get(key).map(|r| r.clone()))
                 .collect(),
         )
     }
@@ -576,6 +562,35 @@ impl InMemoryCache {
             .map(|r| r.clone())
     }
 
+    /// Gets the highest role of a member.
+    ///
+    /// This requires both the [`GUILDS`] and [`GUILD_MEMBERS`] intents.
+    ///
+    /// [`GUILDS`]: twilight_model::gateway::Intents::GUILDS
+    /// [`GUILD_MEMBERS`]: twilight_model::gateway::Intents::GUILD_MEMBERS
+    pub fn member_highest_role(&self, guild_id: GuildId, user_id: UserId) -> Option<RoleId> {
+        let member = match self.0.members.get(&(guild_id, user_id)) {
+            Some(member) => member,
+            None => return None,
+        };
+
+        let mut highest_role: Option<(i64, RoleId)> = None;
+
+        for role_id in &member.roles {
+            if let Some(role) = self.role(*role_id) {
+                if let Some((position, id)) = highest_role {
+                    if role.position < position || (role.position == position && role.id > id) {
+                        continue;
+                    }
+                }
+
+                highest_role = Some((role.position, role.id));
+            }
+        }
+
+        highest_role.map(|(_, id)| id)
+    }
+
     fn new_with_config(config: Config) -> Self {
         Self(Arc::new(InMemoryCacheRef {
             config,
@@ -671,6 +686,7 @@ mod tests {
     use crate::{test, InMemoryCache};
     use twilight_model::{
         gateway::payload::RoleDelete,
+        guild::{Member, Permissions, Role},
         id::{EmojiId, GuildId, RoleId, UserId},
     };
 
@@ -692,4 +708,59 @@ mod tests {
         assert!(cache.0.emojis.is_empty());
         assert!(cache.0.members.is_empty());
     }
+
+    #[test]
+    fn test_highest_role() {
+        let cache = InMemoryCache::new();
+        let guild_id = GuildId(1);
+        let user = test::user(UserId(1));
+        cache.cache_member(
+            guild_id,
+            Member {
+                deaf: false,
+                guild_id,
+                hoisted_role: None,
+                joined_at: None,
+                mute: false,
+                nick: None,
+                pending: false,
+                premium_since: None,
+                roles: vec![RoleId(1), RoleId(2)],
+                user,
+            },
+        );
+
+        cache.cache_roles(
+            guild_id,
+            vec![
+                Role {
+                    color: 0,
+                    hoist: false,
+                    id: RoleId(1),
+                    managed: false,
+                    mentionable: false,
+                    name: "test".to_owned(),
+                    permissions: Permissions::empty(),
+                    position: 0,
+                    tags: None,
+                },
+                Role {
+                    color: 0,
+                    hoist: false,
+                    id: RoleId(2),
+                    managed: false,
+                    mentionable: false,
+                    name: "test".to_owned(),
+                    permissions: Permissions::empty(),
+                    position: 1,
+                    tags: None,
+                },
+            ],
+        );
+
+        assert_eq!(
+            cache.member_highest_role(guild_id, UserId(1)),
+            Some(RoleId(2))
+        );
+    }
 }
