@@ -1,22 +1,33 @@
 use serde::Serialize;
-use std::sync::Arc;
 use twilight_model::{
+    application::interaction::application_command::InteractionMember,
     guild::{Member, PartialMember},
-    id::{GuildId, RoleId},
-    user::User,
+    id::{GuildId, RoleId, UserId},
 };
 
+/// Represents a cached [`Member`].
+///
+/// [`Member`]: twilight_model::guild::Member
 #[derive(Clone, Debug, Eq, PartialEq, Serialize)]
 pub struct CachedMember {
-    pub deaf: bool,
+    /// Whether the member is deafened in a voice channel.
+    pub deaf: Option<bool>,
+    /// ID of the guild this member is a part of.
     pub guild_id: GuildId,
+    /// ISO 8601 timestamp of this member's join date.
     pub joined_at: Option<String>,
-    pub mute: bool,
+    /// Whether the member is muted in a voice channel.
+    pub mute: Option<bool>,
+    /// Nickname of the member.
     pub nick: Option<String>,
+    /// Whether the member has not yet passed the guild's Membership Screening requirements.
     pub pending: bool,
+    /// ISO 8601 timestamp of the date the member boosted the guild.
     pub premium_since: Option<String>,
+    /// List of role IDs this member has.
     pub roles: Vec<RoleId>,
-    pub user: Arc<User>,
+    /// ID of the user relating to the member.
+    pub user_id: UserId,
 }
 
 impl PartialEq<Member> for CachedMember {
@@ -29,14 +40,16 @@ impl PartialEq<Member> for CachedMember {
             self.pending,
             self.premium_since.as_ref(),
             &self.roles,
+            self.user_id,
         ) == (
-            other.deaf,
+            Some(other.deaf),
             other.joined_at.as_ref(),
-            other.mute,
+            Some(other.mute),
             &other.nick,
             other.pending,
             other.premium_since.as_ref(),
             &other.roles,
+            self.user_id,
         )
     }
 }
@@ -51,9 +64,25 @@ impl PartialEq<&PartialMember> for CachedMember {
             &self.premium_since,
             &self.roles,
         ) == (
-            other.deaf,
+            Some(other.deaf),
+            other.joined_at.as_ref(),
+            Some(other.mute),
+            &other.nick,
+            &other.premium_since,
+            &other.roles,
+        )
+    }
+}
+
+impl PartialEq<&InteractionMember> for CachedMember {
+    fn eq(&self, other: &&InteractionMember) -> bool {
+        (
+            self.joined_at.as_ref(),
+            &self.nick,
+            &self.premium_since,
+            &self.roles,
+        ) == (
             other.joined_at.as_ref(),
-            other.mute,
             &other.nick,
             &other.premium_since,
             &other.roles,
@@ -64,24 +93,36 @@ impl PartialEq<&PartialMember> for CachedMember {
 #[cfg(test)]
 mod tests {
     use super::CachedMember;
-    use std::sync::Arc;
+    use static_assertions::assert_fields;
     use twilight_model::{
         guild::{Member, PartialMember},
         id::{GuildId, RoleId, UserId},
         user::User,
     };
 
+    assert_fields!(
+        CachedMember: deaf,
+        guild_id,
+        joined_at,
+        mute,
+        nick,
+        pending,
+        premium_since,
+        roles,
+        user_id
+    );
+
     fn cached_member() -> CachedMember {
         CachedMember {
-            deaf: false,
+            deaf: Some(false),
             guild_id: GuildId(3),
             joined_at: None,
-            mute: true,
+            mute: Some(true),
             nick: Some("member nick".to_owned()),
             pending: false,
             premium_since: None,
             roles: Vec::new(),
-            user: Arc::new(user()),
+            user_id: user().id,
         }
     }
 
@@ -128,8 +169,10 @@ mod tests {
             joined_at: None,
             mute: true,
             nick: Some("member nick".to_owned()),
+            permissions: None,
             premium_since: None,
             roles: Vec::new(),
+            user: None,
         };
 
         assert_eq!(cached_member(), &member);
