@@ -4,7 +4,7 @@ use twilight_model::{
         embed::Embed,
         message::{
             sticker::MessageSticker, Message, MessageActivity, MessageApplication, MessageFlags,
-            MessageReaction, MessageReference, MessageType, Sticker,
+            MessageReaction, MessageReference, MessageType,
         },
         Attachment, ChannelMention,
     },
@@ -59,9 +59,6 @@ pub struct CachedMessage {
     pub reactions: Vec<MessageReaction>,
     /// Message reference.
     pub reference: Option<MessageReference>,
-    #[allow(missing_docs)]
-    #[deprecated(since = "0.5.2", note = "use `sticker_items`")]
-    pub stickers: Vec<Sticker>,
     /// Stickers within the message.
     pub sticker_items: Vec<MessageSticker>,
     /// ISO 8601 timestamp of the date the message was sent.
@@ -74,7 +71,6 @@ pub struct CachedMessage {
 
 impl From<Message> for CachedMessage {
     fn from(msg: Message) -> Self {
-        #[allow(deprecated)]
         Self {
             id: msg.id,
             activity: msg.activity,
@@ -96,7 +92,6 @@ impl From<Message> for CachedMessage {
             pinned: msg.pinned,
             reactions: msg.reactions,
             reference: msg.reference,
-            stickers: Vec::new(),
             sticker_items: msg.sticker_items,
             timestamp: msg.timestamp,
             tts: msg.tts,
